/*******************************************************************************
    sru.h
    Header file for SRU register assignments
    Last modified: 10/9/2004
*******************************************************************************/


// We need the following header file for the SRU register address definitions
#ifndef __DEF21262_H_
#include <def21262.h>
#endif


//==============================================================================
//  Macro: SRU
//  Reads, modifies and writes back a particular SRU register to change a single
//  SRU assignment (i.e. selects an input to an output).
//==============================================================================
#ifdef _LANGUAGE_C
#define SRU(out,in)                      \
  * (volatile unsigned int *) in##_REG &= sru_mask(out,in); \
  * (volatile unsigned int *) in##_REG |= sru_field(out,in); \
  
#else
  
#define SRU(out,in)         \
    r0=dm(in##_REG);       \
    r1=sru_mask(out,in);    \
    r0=r0 and r1;           \
    r1=sru_field(out,in);   \
    r0=r0 or r1;            \
    dm(in##_REG)=r0;
    
#endif   

    
//==============================================================================
//  Macro: sru_field
//  Creates the bit field for a given input and output signal.
//==============================================================================
#define sru_field(out,in) \
    (((in##_GROUP & GROUP_A) >> LOG_GROUP_A) * A_##out \
    |((in##_GROUP & GROUP_B) >> LOG_GROUP_B) * B_##out \
    |((in##_GROUP & GROUP_C) >> LOG_GROUP_C) * C_##out \
    |((in##_GROUP & GROUP_D) >> LOG_GROUP_D) * D_##out \
    |((in##_GROUP & GROUP_E) >> LOG_GROUP_E) * E_##out \
    |((in##_GROUP & GROUP_F) >> LOG_GROUP_F) * F_##out \
    |((in##_GROUP & GROUP_G) >> LOG_GROUP_G) * G_##out ) << in##_SHIFT

        
//==============================================================================
//  Macro: sru_mask
//  Creates a mask which can be used for clearing the bitfield belonging
//  to the given input and output signal. 
//==============================================================================
#define sru_mask(out,in) \
     ~((((in##_GROUP & GROUP_A) >> LOG_GROUP_A) * MASK_A \
       |((in##_GROUP & GROUP_B) >> LOG_GROUP_B) * MASK_B \
       |((in##_GROUP & GROUP_C) >> LOG_GROUP_C) * MASK_C \
       |((in##_GROUP & GROUP_D) >> LOG_GROUP_D) * MASK_D \
       |((in##_GROUP & GROUP_E) >> LOG_GROUP_E) * MASK_E \
       |((in##_GROUP & GROUP_F) >> LOG_GROUP_F) * MASK_F \
       |((in##_GROUP & GROUP_G) >> LOG_GROUP_G) * MASK_G ) << in##_SHIFT)

       
// Logarithm of Group ID Numbers   
#define LOG_GROUP_A     0        
#define LOG_GROUP_B     1        
#define LOG_GROUP_C     2        
#define LOG_GROUP_D     3        
#define LOG_GROUP_E     4        
#define LOG_GROUP_F     5        
#define LOG_GROUP_G     6        
       
// Group ID numbers
#define GROUP_A         (0x01 << LOG_GROUP_A)
#define GROUP_B         (0x01 << LOG_GROUP_B)
#define GROUP_C         (0x01 << LOG_GROUP_C)
#define GROUP_D         (0x01 << LOG_GROUP_D)
#define GROUP_E         (0x01 << LOG_GROUP_E)
#define GROUP_F         (0x01 << LOG_GROUP_F)
#define GROUP_G         (0x01 << LOG_GROUP_G)
         
// Group Base Masks
// The actual field masks can be computed by shifting them to the proper
// location
#define MASK_A          0x1f    
#define MASK_B          0x3f    
#define MASK_C          0x1f    
#define MASK_D          0x3f    
#define MASK_E          0x1f    
#define MASK_F          0x3f    
#define MASK_G          0x01


//==============================================================================
//  Group A - Serial Clock Signals
//==============================================================================

//--------------------------------------------
//  Group ID Assignments
//--------------------------------------------
#define SPORT0_CLK_I_GROUP      GROUP_A  
#define SPORT1_CLK_I_GROUP      GROUP_A         
#define SPORT2_CLK_I_GROUP      GROUP_A         
#define SPORT3_CLK_I_GROUP      GROUP_A         
#define SPORT4_CLK_I_GROUP      GROUP_A         
#define SPORT5_CLK_I_GROUP      GROUP_A 

#define PDAP_CLK_I_GROUP        GROUP_A
#define IDP0_CLK_I_GROUP        GROUP_A
#define IDP1_CLK_I_GROUP        GROUP_A
#define IDP2_CLK_I_GROUP        GROUP_A

#define IDP3_CLK_I_GROUP        GROUP_A
#define IDP4_CLK_I_GROUP        GROUP_A
#define IDP5_CLK_I_GROUP        GROUP_A
#define IDP6_CLK_I_GROUP        GROUP_A
#define IDP7_CLK_I_GROUP        GROUP_A

#define PCG_EXTA_I_GROUP        GROUP_A
#define PCG_EXTB_I_GROUP        GROUP_A

//--------------------------------------------
//  Register Assignments
//--------------------------------------------
#define SPORT0_CLK_I_REG        SRU_CLK0
#define SPORT1_CLK_I_REG        SRU_CLK0         
#define SPORT2_CLK_I_REG        SRU_CLK0         
#define SPORT3_CLK_I_REG        SRU_CLK0         
#define SPORT4_CLK_I_REG        SRU_CLK0         
#define SPORT5_CLK_I_REG        SRU_CLK0
 
#define PDAP_CLK_I_REG          SRU_CLK1
#define IDP0_CLK_I_REG          SRU_CLK1
#define IDP1_CLK_I_REG          SRU_CLK1
#define IDP2_CLK_I_REG          SRU_CLK1
        
#define IDP3_CLK_I_REG          SRU_CLK2
#define IDP4_CLK_I_REG          SRU_CLK2
#define IDP5_CLK_I_REG          SRU_CLK2
#define IDP6_CLK_I_REG          SRU_CLK2
#define IDP7_CLK_I_REG          SRU_CLK2

#define PCG_EXTA_I_REG          SRU_CLK3
#define PCG_EXTB_I_REG          SRU_CLK3

//--------------------------------------------
//  Shift Values for Bit Fields
//--------------------------------------------

// SRU_CLK0
#define SPORT0_CLK_I_SHIFT      0
#define SPORT1_CLK_I_SHIFT      5
#define SPORT2_CLK_I_SHIFT      10
#define SPORT3_CLK_I_SHIFT      15
#define SPORT4_CLK_I_SHIFT      20
#define SPORT5_CLK_I_SHIFT      25
     
// SRU_CLK1
#define PDAP_CLK_I_SHIFT		15
#define IDP0_CLK_I_SHIFT        15
#define IDP1_CLK_I_SHIFT        20
#define IDP2_CLK_I_SHIFT        25

// SRU_CLK2
#define IDP3_CLK_I_SHIFT        0
#define IDP4_CLK_I_SHIFT        5
#define IDP5_CLK_I_SHIFT        10
#define IDP6_CLK_I_SHIFT        15
#define IDP7_CLK_I_SHIFT        20

// SRU_CLK3
#define PCG_EXTA_I_SHIFT        0
#define PCG_EXTB_I_SHIFT        5

//--------------------------------------------
//  Bit Field Codes
//--------------------------------------------
#define A_DAI_PB01_O            0x00
#define A_DAI_PB02_O            0x01
#define A_DAI_PB03_O            0x02
#define A_DAI_PB04_O            0x03
#define A_DAI_PB05_O            0x04
#define A_DAI_PB06_O            0x05
#define A_DAI_PB07_O            0x06
#define A_DAI_PB08_O            0x07
#define A_DAI_PB09_O            0x08
#define A_DAI_PB10_O            0x09
#define A_DAI_PB11_O            0x0a
#define A_DAI_PB12_O            0x0b
#define A_DAI_PB13_O            0x0c
#define A_DAI_PB14_O            0x0d
#define A_DAI_PB15_O            0x0e
#define A_DAI_PB16_O            0x0f
#define A_DAI_PB17_O            0x10
#define A_DAI_PB18_O            0x11
#define A_DAI_PB19_O            0x12
#define A_DAI_PB20_O            0x13
#define A_SPORT0_CLK_O          0x14
#define A_SPORT1_CLK_O          0x15
#define A_SPORT2_CLK_O          0x16
#define A_SPORT3_CLK_O          0x17
#define A_SPORT4_CLK_O          0x18
#define A_SPORT5_CLK_O          0x19
#define A_PCG_CLKA_O            0x1c
#define A_PCG_CLKB_O            0x1d
#define A_LOW                   0x1e
#define A_HIGH                  0x1f


//==============================================================================
//  Group B - Serial Data Signals
//==============================================================================

//--------------------------------------------
//  Group ID Assignments
//--------------------------------------------
#define SPORT0_DA_I_GROUP       GROUP_B
#define SPORT0_DB_I_GROUP       GROUP_B
#define SPORT1_DA_I_GROUP       GROUP_B
#define SPORT1_DB_I_GROUP       GROUP_B
#define SPORT2_DA_I_GROUP       GROUP_B

#define SPORT2_DB_I_GROUP       GROUP_B
#define SPORT3_DA_I_GROUP       GROUP_B
#define SPORT3_DB_I_GROUP       GROUP_B
#define SPORT4_DA_I_GROUP       GROUP_B
#define SPORT4_DB_I_GROUP       GROUP_B

#define SPORT5_DA_I_GROUP       GROUP_B
#define SPORT5_DB_I_GROUP       GROUP_B

#define IDP0_DAT_I_GROUP        GROUP_B
#define IDP1_DAT_I_GROUP        GROUP_B
#define IDP2_DAT_I_GROUP        GROUP_B
#define IDP3_DAT_I_GROUP        GROUP_B

#define IDP4_DAT_I_GROUP        GROUP_B
#define IDP5_DAT_I_GROUP        GROUP_B
#define IDP6_DAT_I_GROUP        GROUP_B
#define IDP7_DAT_I_GROUP        GROUP_B

//--------------------------------------------
//  Register Assignments
//--------------------------------------------
#define SPORT0_DA_I_REG         SRU_DAT0
#define SPORT0_DB_I_REG         SRU_DAT0
#define SPORT1_DA_I_REG         SRU_DAT0
#define SPORT1_DB_I_REG         SRU_DAT0
#define SPORT2_DA_I_REG         SRU_DAT0

#define SPORT2_DB_I_REG         SRU_DAT1
#define SPORT3_DA_I_REG         SRU_DAT1
#define SPORT3_DB_I_REG         SRU_DAT1
#define SPORT4_DA_I_REG         SRU_DAT1
#define SPORT4_DB_I_REG         SRU_DAT1

#define SPORT5_DA_I_REG         SRU_DAT2
#define SPORT5_DB_I_REG         SRU_DAT2

#define IDP0_DAT_I_REG          SRU_DAT3
#define IDP1_DAT_I_REG          SRU_DAT3
#define IDP2_DAT_I_REG          SRU_DAT3
#define IDP3_DAT_I_REG          SRU_DAT3

#define IDP4_DAT_I_REG          SRU_DAT4
#define IDP5_DAT_I_REG          SRU_DAT4
#define IDP6_DAT_I_REG          SRU_DAT4
#define IDP7_DAT_I_REG          SRU_DAT4

//--------------------------------------------
//  Shift Values for Bit Fields
//--------------------------------------------

// SRU_DAT0
#define SPORT0_DA_I_SHIFT       0
#define SPORT0_DB_I_SHIFT       6
#define SPORT1_DA_I_SHIFT       12
#define SPORT1_DB_I_SHIFT       18
#define SPORT2_DA_I_SHIFT       24

// SRU_DAT1
#define SPORT2_DB_I_SHIFT       0
#define SPORT3_DA_I_SHIFT       6
#define SPORT3_DB_I_SHIFT       12
#define SPORT4_DA_I_SHIFT       18
#define SPORT4_DB_I_SHIFT       24

// SRU_DAT2
#define SPORT5_DA_I_SHIFT       0
#define SPORT5_DB_I_SHIFT       6

// SRU_DAT3
#define IDP0_DAT_I_SHIFT        6
#define IDP1_DAT_I_SHIFT        12
#define IDP2_DAT_I_SHIFT        18
#define IDP3_DAT_I_SHIFT        24

// SRU_DAT4
#define IDP4_DAT_I_SHIFT        0
#define IDP5_DAT_I_SHIFT        6
#define IDP6_DAT_I_SHIFT        12
#define IDP7_DAT_I_SHIFT        18

//--------------------------------------------
//  Bit Field Codes
//--------------------------------------------
#define B_DAI_PB01_O            0x00
#define B_DAI_PB02_O            0x01
#define B_DAI_PB03_O            0x02
#define B_DAI_PB04_O            0x03
#define B_DAI_PB05_O            0x04
#define B_DAI_PB06_O            0x05
#define B_DAI_PB07_O            0x06
#define B_DAI_PB08_O            0x07
#define B_DAI_PB09_O            0x08
#define B_DAI_PB10_O            0x09
#define B_DAI_PB11_O            0x0a
#define B_DAI_PB12_O            0x0b
#define B_DAI_PB13_O            0x0c
#define B_DAI_PB14_O            0x0d
#define B_DAI_PB15_O            0x0e
#define B_DAI_PB16_O            0x0f
#define B_DAI_PB17_O            0x10
#define B_DAI_PB18_O            0x11
#define B_DAI_PB19_O            0x12
#define B_DAI_PB20_O            0x13
#define B_SPORT0_DA_O           0x14
#define B_SPORT0_DB_O           0x15
#define B_SPORT1_DA_O           0x16
#define B_SPORT1_DB_O           0x17
#define B_SPORT2_DA_O           0x18
#define B_SPORT2_DB_O           0x19
#define B_SPORT3_DA_O           0x1a
#define B_SPORT3_DB_O           0x1b
#define B_SPORT4_DA_O           0x1c
#define B_SPORT4_DB_O           0x1d
#define B_SPORT5_DA_O           0x1e
#define B_SPORT5_DB_O           0x1f
#define B_LOW                   0x2a
#define B_HIGH                  0x2b


//==============================================================================
//  Group C - Fame Sync Signals
//==============================================================================

//--------------------------------------------
//  Group ID Assignments
//--------------------------------------------
#define SPORT0_FS_I_GROUP       GROUP_C
#define SPORT1_FS_I_GROUP       GROUP_C
#define SPORT2_FS_I_GROUP       GROUP_C
#define SPORT3_FS_I_GROUP       GROUP_C
#define SPORT4_FS_I_GROUP       GROUP_C
#define SPORT5_FS_I_GROUP       GROUP_C

#define PDAP_HOLD_I_GROUP       GROUP_C
#define IDP0_FS_I_GROUP         GROUP_C
#define IDP1_FS_I_GROUP         GROUP_C
#define IDP2_FS_I_GROUP         GROUP_C

#define IDP3_FS_I_GROUP         GROUP_C
#define IDP4_FS_I_GROUP         GROUP_C
#define IDP5_FS_I_GROUP         GROUP_C
#define IDP6_FS_I_GROUP         GROUP_C
#define IDP7_FS_I_GROUP         GROUP_C

//--------------------------------------------
//  Register Assignments
//--------------------------------------------
#define SPORT0_FS_I_REG         SRU_FS0
#define SPORT1_FS_I_REG         SRU_FS0
#define SPORT2_FS_I_REG         SRU_FS0
#define SPORT3_FS_I_REG         SRU_FS0
#define SPORT4_FS_I_REG         SRU_FS0
#define SPORT5_FS_I_REG         SRU_FS0

#define PDAP_HOLD_I_REG         SRU_FS2
#define IDP0_FS_I_REG           SRU_FS1
#define IDP1_FS_I_REG           SRU_FS1
#define IDP2_FS_I_REG           SRU_FS1

#define IDP3_FS_I_REG           SRU_FS2
#define IDP4_FS_I_REG           SRU_FS2
#define IDP5_FS_I_REG           SRU_FS2
#define IDP6_FS_I_REG           SRU_FS2
#define IDP7_FS_I_REG           SRU_FS2

//--------------------------------------------
//  Shift Values for Bit Fields
//--------------------------------------------

// SRU_FS0
#define SPORT0_FS_I_SHIFT       0
#define SPORT1_FS_I_SHIFT       5
#define SPORT2_FS_I_SHIFT       10
#define SPORT3_FS_I_SHIFT       15
#define SPORT4_FS_I_SHIFT       20
#define SPORT5_FS_I_SHIFT       25

// SRU_FS1
#define PDAP_HOLD_I_SHIFT       15 
#define IDP0_FS_I_SHIFT         15
#define IDP1_FS_I_SHIFT         20
#define IDP2_FS_I_SHIFT         25

// SRU_FS2
#define IDP3_FS_I_SHIFT         0
#define IDP4_FS_I_SHIFT         5
#define IDP5_FS_I_SHIFT         10
#define IDP6_FS_I_SHIFT         15
#define IDP7_FS_I_SHIFT         20

//--------------------------------------------
//  Bit Field Codes
//--------------------------------------------
#define C_DAI_PB01_O            0x00
#define C_DAI_PB02_O            0x01
#define C_DAI_PB03_O            0x02
#define C_DAI_PB04_O            0x03
#define C_DAI_PB05_O            0x04
#define C_DAI_PB06_O            0x05
#define C_DAI_PB07_O            0x06
#define C_DAI_PB08_O            0x07
#define C_DAI_PB09_O            0x08
#define C_DAI_PB10_O            0x09
#define C_DAI_PB11_O            0x0a
#define C_DAI_PB12_O            0x0b
#define C_DAI_PB13_O            0x0c
#define C_DAI_PB14_O            0x0d
#define C_DAI_PB15_O            0x0e
#define C_DAI_PB16_O            0x0f
#define C_DAI_PB17_O            0x10
#define C_DAI_PB18_O            0x11
#define C_DAI_PB19_O            0x12
#define C_DAI_PB20_O            0x13
#define C_SPORT0_FS_O           0x14
#define C_SPORT1_FS_O           0x15
#define C_SPORT2_FS_O           0x16
#define C_SPORT3_FS_O           0x17
#define C_SPORT4_FS_O           0x18
#define C_SPORT5_FS_O           0x19
#define C_PCG_FSA_O             0x1c
#define C_PCG_FSB_O             0x1d
#define C_LOW                   0x1e
#define C_HIGH                  0x1f

//==============================================================================
//  Group D - Pin Input Signals
//==============================================================================

//--------------------------------------------
//  Group ID Assignments
//--------------------------------------------
#define DAI_PB01_I_GROUP        GROUP_D
#define DAI_PB02_I_GROUP        GROUP_D
#define DAI_PB03_I_GROUP        GROUP_D
#define DAI_PB04_I_GROUP        GROUP_D
#define DAI_PB05_I_GROUP        GROUP_D

#define DAI_PB06_I_GROUP        GROUP_D
#define DAI_PB07_I_GROUP        GROUP_D
#define DAI_PB08_I_GROUP        GROUP_D
#define DAI_PB09_I_GROUP        GROUP_D
#define DAI_PB10_I_GROUP        GROUP_D

#define DAI_PB11_I_GROUP        GROUP_D
#define DAI_PB12_I_GROUP        GROUP_D
#define DAI_PB13_I_GROUP        GROUP_D
#define DAI_PB14_I_GROUP        GROUP_D
#define DAI_PB15_I_GROUP        GROUP_D

#define DAI_PB16_I_GROUP        GROUP_D
#define DAI_PB17_I_GROUP        GROUP_D
#define DAI_PB18_I_GROUP        GROUP_D
#define DAI_PB19_I_GROUP        GROUP_D
#define DAI_PB20_I_GROUP        GROUP_D

#define DAI_PB19_INVERT_GROUP   GROUP_G
#define DAI_PB20_INVERT_GROUP   GROUP_G

//--------------------------------------------
//  Register Assignments
//--------------------------------------------
#define DAI_PB01_I_REG          SRU_PIN0
#define DAI_PB02_I_REG          SRU_PIN0
#define DAI_PB03_I_REG          SRU_PIN0
#define DAI_PB04_I_REG          SRU_PIN0
#define DAI_PB05_I_REG          SRU_PIN0

#define DAI_PB06_I_REG          SRU_PIN1
#define DAI_PB07_I_REG          SRU_PIN1
#define DAI_PB08_I_REG          SRU_PIN1
#define DAI_PB09_I_REG          SRU_PIN1
#define DAI_PB10_I_REG          SRU_PIN1

#define DAI_PB11_I_REG          SRU_PIN2
#define DAI_PB12_I_REG          SRU_PIN2
#define DAI_PB13_I_REG          SRU_PIN2
#define DAI_PB14_I_REG          SRU_PIN2
#define DAI_PB15_I_REG          SRU_PIN2

#define DAI_PB16_I_REG          SRU_PIN3
#define DAI_PB17_I_REG          SRU_PIN3
#define DAI_PB18_I_REG          SRU_PIN3
#define DAI_PB19_I_REG          SRU_PIN3
#define DAI_PB20_I_REG          SRU_PIN3

#define DAI_PB19_INVERT_REG     SRU_PIN3
#define DAI_PB20_INVERT_REG     SRU_PIN3

//--------------------------------------------
//  Shift Values for Bit Fields
//--------------------------------------------

// SRU_PIN0
#define DAI_PB01_I_SHIFT        0
#define DAI_PB02_I_SHIFT        6
#define DAI_PB03_I_SHIFT        12
#define DAI_PB04_I_SHIFT        18
#define DAI_PB05_I_SHIFT        24

// SRU_PIN1
#define DAI_PB06_I_SHIFT        0
#define DAI_PB07_I_SHIFT        6
#define DAI_PB08_I_SHIFT        12
#define DAI_PB09_I_SHIFT        18
#define DAI_PB10_I_SHIFT        24

// SRU_PIN2
#define DAI_PB11_I_SHIFT        0
#define DAI_PB12_I_SHIFT        6
#define DAI_PB13_I_SHIFT        12
#define DAI_PB14_I_SHIFT        18
#define DAI_PB15_I_SHIFT        24

// SRU_PIN3
#define DAI_PB16_I_SHIFT        0
#define DAI_PB17_I_SHIFT        6
#define DAI_PB18_I_SHIFT        12
#define DAI_PB19_I_SHIFT        18
#define DAI_PB20_I_SHIFT        24
#define DAI_PB19_INVERT_SHIFT   30
#define DAI_PB20_INVERT_SHIFT   31


//--------------------------------------------
//  Bit Field Codes
//--------------------------------------------
#define D_DAI_PB01_O            0x00
#define D_DAI_PB02_O            0x01
#define D_DAI_PB03_O            0x02
#define D_DAI_PB04_O            0x03
#define D_DAI_PB05_O            0x04
#define D_DAI_PB06_O            0x05
#define D_DAI_PB07_O            0x06
#define D_DAI_PB08_O            0x07
#define D_DAI_PB09_O            0x08
#define D_DAI_PB10_O            0x09
#define D_DAI_PB11_O            0x0a
#define D_DAI_PB12_O            0x0b
#define D_DAI_PB13_O            0x0c
#define D_DAI_PB14_O            0x0d
#define D_DAI_PB15_O            0x0e
#define D_DAI_PB16_O            0x0f
#define D_DAI_PB17_O            0x10
#define D_DAI_PB18_O            0x11
#define D_DAI_PB19_O            0x12
#define D_DAI_PB20_O            0x13
#define D_SPORT0_DA_O           0x14
#define D_SPORT0_DB_O           0x15
#define D_SPORT1_DA_O           0x16
#define D_SPORT1_DB_O           0x17
#define D_SPORT2_DA_O           0x18
#define D_SPORT2_DB_O           0x19
#define D_SPORT3_DA_O           0x1a
#define D_SPORT3_DB_O           0x1b
#define D_SPORT4_DA_O           0x1c
#define D_SPORT4_DB_O           0x1d
#define D_SPORT5_DA_O           0x1e
#define D_SPORT5_DB_O           0x1f
#define D_SPORT0_CLK_O          0x20
#define D_SPORT1_CLK_O          0x21
#define D_SPORT2_CLK_O          0x22
#define D_SPORT3_CLK_O          0x23
#define D_SPORT4_CLK_O          0x24
#define D_SPORT5_CLK_O          0x25
#define D_SPORT0_FS_O           0x26
#define D_SPORT1_FS_O           0x27
#define D_SPORT2_FS_O           0x28
#define D_SPORT3_FS_O           0x29
#define D_SPORT4_FS_O           0x2a
#define D_SPORT5_FS_O           0x2b
#define D_TIMER0_O              0x2c
#define D_TIMER1_O              0x2d
#define D_TIMER2_O              0x2e
#define D_FLAG10_O              0x2f
#define D_MISCB2_O              0x30
#define D_MISCB3_O              0x31
#define D_MISCB4_O              0x32
#define D_MISCB5_O              0x33
#define D_FLAG11_O              0x34
#define D_FLAG12_O              0x35
#define D_FLAG13_O              0x36
#define D_FLAG14_O              0x37
#define D_PCG_CLKA_O            0x38
#define D_PCG_CLKB_O            0x39
#define D_PCG_FSA_O             0x3a
#define D_PCG_FSB_O             0x3b
#define D_FLAG15_O              0x3c
#define D_LOW                   0x3e
#define D_HIGH                  0x3f


//==============================================================================
//  Group E - Miscellaneous SRU Signals
//==============================================================================

//--------------------------------------------
//  Group ID Assignments
//--------------------------------------------
#define MISCA0_I_GROUP          GROUP_E
#define DAI_INT_28_I_GROUP		GROUP_E
#define FLAG13_I_GROUP			GROUP_E
#define MISCA1_I_GROUP			GROUP_E
#define DAI_INT_29_I_GROUP		GROUP_E
#define FLAG14_I_GROUP			GROUP_E
#define MISCA2_I_GROUP			GROUP_E
#define DAI_INT_30_I_GROUP		GROUP_E
#define FLAG15_I_GROUP			GROUP_E
#define MISCA3_I_GROUP			GROUP_E
#define DAI_INT_31_I_GROUP		GROUP_E
#define MISCA4_I_GROUP			GROUP_E
#define MISCA5_I_GROUP			GROUP_E

#define INV_MISCA4_I_GROUP      GROUP_G
#define INV_MISCA5_I_GROUP      GROUP_G

#define MISCB0_I_GROUP          GROUP_E
#define DAI_INT_22_I_GROUP		GROUP_E
#define TIMER0_I_GROUP			GROUP_E
#define MISCB1_I_GROUP          GROUP_E
#define DAI_INT_23_I_GROUP		GROUP_E
#define TIMER1_I_GROUP			GROUP_E
#define MISCB2_I_GROUP          GROUP_E
#define DAI_INT_24_I_GROUP		GROUP_E
#define TIMER2_I_GROUP			GROUP_E
#define MISCB3_I_GROUP          GROUP_E
#define DAI_INT_25_I_GROUP		GROUP_E
#define FLAG10_I_GROUP			GROUP_E
#define MISCB4_I_GROUP          GROUP_E
#define DAI_INT_26_I_GROUP		GROUP_E
#define FLAG11_I_GROUP			GROUP_E
#define MISCB5_I_GROUP          GROUP_E
#define DAI_INT_27_I_GROUP		GROUP_E
#define FLAG12_I_GROUP			GROUP_E



//--------------------------------------------
//  Register Assignments
//--------------------------------------------
#define MISCA0_I_REG            SRU_EXT_MISCA
#define DAI_INT_28_I_REG        SRU_EXT_MISCA
#define FLAG13_I_REG            SRU_EXT_MISCA
#define MISCA1_I_REG            SRU_EXT_MISCA
#define DAI_INT_29_I_REG        SRU_EXT_MISCA
#define FLAG14_I_REG            SRU_EXT_MISCA
#define MISCA2_I_REG            SRU_EXT_MISCA
#define DAI_INT_30_I_REG        SRU_EXT_MISCA
#define FLAG15_I_REG            SRU_EXT_MISCA
#define MISCA3_I_REG            SRU_EXT_MISCA
#define DAI_INT_31_I_REG        SRU_EXT_MISCA
#define MISCA4_I_REG            SRU_EXT_MISCA
#define MISCA5_I_REG            SRU_EXT_MISCA

#define INV_MISCA4_I_REG        SRU_EXT_MISCA
#define INV_MISCA5_I_REG        SRU_EXT_MISCA

#define MISCB0_I_REG            SRU_EXT_MISCB
#define DAI_INT_22_I_REG        SRU_EXT_MISCB
#define TIMER0_I_REG            SRU_EXT_MISCB
#define MISCB1_I_REG            SRU_EXT_MISCB
#define DAI_INT_23_I_REG        SRU_EXT_MISCB 
#define TIMER1_I_REG            SRU_EXT_MISCB
#define MISCB2_I_REG            SRU_EXT_MISCB
#define DAI_INT_24_I_REG        SRU_EXT_MISCB
#define TIMER2_I_REG            SRU_EXT_MISCB
#define MISCB3_I_REG            SRU_EXT_MISCB
#define DAI_INT_25_I_REG        SRU_EXT_MISCB
#define FLAG10_I_REG            SRU_EXT_MISCB
#define MISCB4_I_REG            SRU_EXT_MISCB
#define DAI_INT_26_I_REG        SRU_EXT_MISCB
#define FLAG11_I_REG            SRU_EXT_MISCB
#define MISCB5_I_REG            SRU_EXT_MISCB
#define DAI_INT_27_I_REG        SRU_EXT_MISCB
#define FLAG12_I_REG            SRU_EXT_MISCB

//--------------------------------------------
//  Shift Values for Bit Fields
//--------------------------------------------

// SRU_EXT_MISCA
#define MISCA0_I_SHIFT          0
#define DAI_INT_28_I_SHIFT      0
#define FLAG13_I_SHIFT          0
#define MISCA1_I_SHIFT          5
#define DAI_INT_29_I_SHIFT      5
#define FLAG14_I_SHIFT          5
#define MISCA2_I_SHIFT          10
#define DAI_INT_30_I_SHIFT      10
#define FLAG15_I_SHIFT          10
#define MISCA3_I_SHIFT          15
#define DAI_INT_31_I_SHIFT      15
#define MISCA4_I_SHIFT          20
#define MISCA5_I_SHIFT          25

#define INV_MISCA4_I_SHIFT      30
#define INV_MISCA5_I_SHIFT      31

// SRU_EXT_MISCB
#define MISCB0_I_SHIFT          0
#define DAI_INT_22_I_SHIFT      0
#define TIMER0_I_SHIFT          0
#define MISCB1_I_SHIFT          5
#define DAI_INT_23_I_SHIFT      5
#define TIMER1_I_SHIFT          5
#define MISCB2_I_SHIFT          10
#define DAI_INT_24_I_SHIFT      10
#define TIMER2_I_SHIFT          10
#define MISCB3_I_SHIFT          15
#define DAI_INT_25_I_SHIFT      15
#define FLAG10_I_SHIFT          15
#define MISCB4_I_SHIFT          20
#define DAI_INT_26_I_SHIFT      20
#define FLAG11_I_SHIFT          20
#define MISCB5_I_SHIFT          25
#define DAI_INT_27_I_SHIFT      25
#define FLAG12_I_SHIFT          25

//--------------------------------------------
//  Bit Field Codes
//--------------------------------------------
#define E_DAI_PB01_O            0x00
#define E_DAI_PB02_O            0x01
#define E_DAI_PB03_O            0x02
#define E_DAI_PB04_O            0x03
#define E_DAI_PB05_O            0x04
#define E_DAI_PB06_O            0x05
#define E_DAI_PB07_O            0x06
#define E_DAI_PB08_O            0x07
#define E_DAI_PB09_O            0x08
#define E_DAI_PB10_O            0x09
#define E_DAI_PB11_O            0x0a
#define E_DAI_PB12_O            0x0b
#define E_DAI_PB13_O            0x0c
#define E_DAI_PB14_O            0x0d
#define E_DAI_PB15_O            0x0e
#define E_DAI_PB16_O            0x0f
#define E_DAI_PB17_O            0x10
#define E_DAI_PB18_O            0x11
#define E_DAI_PB19_O            0x12
#define E_DAI_PB20_O            0x13
#define E_TIMER0_O              0x14
#define E_TIMER1_O              0x15
#define E_TIMER2_O              0x16
#define E_PDAP_STRB_O           0x19
#define E_PCG_CLKA_O            0x1a
#define E_PCG_FSA_O             0x1b
#define E_PCG_CLKB_O            0x1c
#define E_PCG_FSB_O             0x1d
#define E_LOW                   0x1e
#define E_HIGH                  0x1f

#define G_LOW                   0x00
#define G_HIGH                  0x01


//==============================================================================
//  Group F - Pin Buffer Enable Signals
//==============================================================================

//--------------------------------------------
//  Group ID Assignments
//--------------------------------------------

#define PBEN01_I_GROUP      GROUP_F
#define PBEN02_I_GROUP      GROUP_F
#define PBEN03_I_GROUP      GROUP_F
#define PBEN04_I_GROUP      GROUP_F
#define PBEN05_I_GROUP      GROUP_F

#define PBEN06_I_GROUP      GROUP_F
#define PBEN07_I_GROUP      GROUP_F
#define PBEN08_I_GROUP      GROUP_F
#define PBEN09_I_GROUP      GROUP_F
#define PBEN10_I_GROUP      GROUP_F

#define PBEN11_I_GROUP      GROUP_F
#define PBEN12_I_GROUP      GROUP_F
#define PBEN13_I_GROUP      GROUP_F
#define PBEN14_I_GROUP      GROUP_F
#define PBEN15_I_GROUP      GROUP_F

#define PBEN16_I_GROUP      GROUP_F
#define PBEN17_I_GROUP      GROUP_F
#define PBEN18_I_GROUP      GROUP_F
#define PBEN19_I_GROUP      GROUP_F
#define PBEN20_I_GROUP      GROUP_F

//--------------------------------------------
//  Resister Assignments
//--------------------------------------------

#define PBEN01_I_REG        SRU_PBEN0
#define PBEN02_I_REG        SRU_PBEN0
#define PBEN03_I_REG        SRU_PBEN0
#define PBEN04_I_REG        SRU_PBEN0
#define PBEN05_I_REG        SRU_PBEN0

#define PBEN06_I_REG        SRU_PBEN1
#define PBEN07_I_REG        SRU_PBEN1
#define PBEN08_I_REG        SRU_PBEN1
#define PBEN09_I_REG        SRU_PBEN1
#define PBEN10_I_REG        SRU_PBEN1

#define PBEN11_I_REG        SRU_PBEN2
#define PBEN12_I_REG        SRU_PBEN2
#define PBEN13_I_REG        SRU_PBEN2
#define PBEN14_I_REG        SRU_PBEN2
#define PBEN15_I_REG        SRU_PBEN2

#define PBEN16_I_REG        SRU_PBEN3
#define PBEN17_I_REG        SRU_PBEN3
#define PBEN18_I_REG        SRU_PBEN3
#define PBEN19_I_REG        SRU_PBEN3
#define PBEN20_I_REG        SRU_PBEN3

//--------------------------------------------
//  Shift Values for Bit Fields
//--------------------------------------------

// SRU_PBEN0
#define PBEN01_I_SHIFT      0
#define PBEN02_I_SHIFT      6
#define PBEN03_I_SHIFT      12
#define PBEN04_I_SHIFT      18
#define PBEN05_I_SHIFT      24

// SRU_PBEN1
#define PBEN06_I_SHIFT      0
#define PBEN07_I_SHIFT      6
#define PBEN08_I_SHIFT      12
#define PBEN09_I_SHIFT      18
#define PBEN10_I_SHIFT      24

// SRU_PBEN2
#define PBEN11_I_SHIFT      0
#define PBEN12_I_SHIFT      6
#define PBEN13_I_SHIFT      12
#define PBEN14_I_SHIFT      18
#define PBEN15_I_SHIFT      24

// SRU_PBEN3
#define PBEN16_I_SHIFT      0
#define PBEN17_I_SHIFT      6
#define PBEN18_I_SHIFT      12
#define PBEN19_I_SHIFT      18
#define PBEN20_I_SHIFT      24

//--------------------------------------------
//  Bit Field Codes
//--------------------------------------------
#define F_LOW                   0x00
#define F_HIGH                  0x01
#define F_MISCA0_O              0x02
#define F_MISCA1_O              0x03
#define F_MISCA2_O             0x04
#define F_MISCA3_O              0x05
#define F_MISCA4_O              0x06
#define F_MISCA5_O              0x07
#define F_SPORT0_CLK_PBEN_O     0x08
#define F_SPORT0_FS_PBEN_O      0x09
#define F_SPORT0_DA_PBEN_O      0x0a
#define F_SPORT0_DB_PBEN_O      0x0b
#define F_SPORT1_CLK_PBEN_O     0x0c
#define F_SPORT1_FS_PBEN_O      0x0d
#define F_SPORT1_DA_PBEN_O      0x0e
#define F_SPORT1_DB_PBEN_O      0x0f
#define F_SPORT2_CLK_PBEN_O     0x10
#define F_SPORT2_FS_PBEN_O      0x11
#define F_SPORT2_DA_PBEN_O      0x12
#define F_SPORT2_DB_PBEN_O      0x13
#define F_SPORT3_CLK_PBEN_O     0x14
#define F_SPORT3_FS_PBEN_O      0x15
#define F_SPORT3_DA_PBEN_O      0x16
#define F_SPORT3_DB_PBEN_O      0x17
#define F_SPORT4_CLK_PBEN_O     0x18
#define F_SPORT4_FS_PBEN_O      0x19
#define F_SPORT4_DA_PBEN_O      0x1a
#define F_SPORT4_DB_PBEN_O      0x1b
#define F_SPORT5_CLK_PBEN_O     0x1c
#define F_SPORT5_FS_PBEN_O      0x1d
#define F_SPORT5_DA_PBEN_O      0x1e
#define F_SPORT5_DB_PBEN_O      0x1f
#define F_TIMER0_PBEN_O         0x20
#define F_TIMER1_PBEN_O         0x21
#define F_TIMER2_PBEN_O         0x22
#define F_FLAG10_PBEN_O         0x23
#define F_FLAG11_PBEN_O         0x24
#define F_FLAG12_PBEN_O         0x25
#define F_FLAG13_PBEN_O         0x26
#define F_FLAG14_PBEN_O         0x27
#define F_FLAG15_PBEN_O         0x28


//==============================================================================
//  Dummy Signals
//  The signals listed below don't exist in the given group but they are
//  required by the preprocessor for evaluating the macros sru_fiels and 
//  sru_mask. The code assigned to them them ara arbitrary.
//==============================================================================

// Group A dummy signals
#define A_SPORT0_DA_O           0
#define A_SPORT0_DB_O           0
#define A_SPORT1_DA_O           0
#define A_SPORT1_DB_O           0
#define A_SPORT2_DA_O           0
#define A_SPORT2_DB_O           0
#define A_SPORT3_DA_O           0
#define A_SPORT3_DB_O           0
#define A_SPORT4_DA_O           0
#define A_SPORT4_DB_O           0
#define A_SPORT5_DA_O           0
#define A_SPORT5_DB_O           0

#define A_SPORT0_FS_O           0
#define A_SPORT1_FS_O           0
#define A_SPORT2_FS_O           0
#define A_SPORT3_FS_O           0
#define A_SPORT4_FS_O           0
#define A_SPORT5_FS_O           0
#define A_PCG_FSA_O             0
#define A_PCG_FSB_O             0

#define A_SPORT0_DA_O           0
#define A_SPORT0_DB_O           0
#define A_SPORT1_DA_O           0
#define A_SPORT1_DB_O           0
#define A_SPORT2_DA_O           0
#define A_SPORT2_DB_O           0
#define A_SPORT3_DA_O           0
#define A_SPORT3_DB_O           0
#define A_SPORT4_DA_O           0
#define A_SPORT4_DB_O           0
#define A_SPORT5_DA_O           0
#define A_SPORT5_DB_O           0
#define A_SPORT0_FS_O           0
#define A_SPORT1_FS_O           0
#define A_SPORT2_FS_O           0
#define A_SPORT3_FS_O           0
#define A_SPORT4_FS_O           0
#define A_SPORT5_FS_O           0
#define A_TIMER0_O              0
#define A_TIMER1_O              0
#define A_TIMER2_O              0
#define A_FLAG10_O              0
#define A_MISCB2_O             0
#define A_MISCB3_O             0
#define A_MISCB4_O             0
#define A_MISCB5_O             0
#define A_FLAG11_O              0
#define A_FLAG12_O              0
#define A_FLAG13_O              0
#define A_FLAG14_O              0
#define A_PCG_FSA_O             0
#define A_PCG_FSB_O             0
#define A_FLAG15_O              0

#define A_TIMER0_O              0
#define A_TIMER1_O              0
#define A_TIMER2_O              0
#define A_PDAP_STRB_O           0
#define A_PCG_FSA_O             0
#define A_PCG_FSB_O             0

#define A_MISCA0_O              0
#define A_MISCA1_O              0
#define A_MISCA2_O              0
#define A_MISCA3_O              0
#define A_MISCA4_O              0
#define A_MISCA5_O              0
#define A_SPORT0_CLK_PBEN_O     0
#define A_SPORT0_FS_PBEN_O      0
#define A_SPORT0_DA_PBEN_O      0
#define A_SPORT0_DB_PBEN_O      0
#define A_SPORT1_CLK_PBEN_O     0
#define A_SPORT1_FS_PBEN_O      0
#define A_SPORT1_DA_PBEN_O      0
#define A_SPORT1_DB_PBEN_O      0
#define A_SPORT2_CLK_PBEN_O     0
#define A_SPORT2_FS_PBEN_O      0
#define A_SPORT2_DA_PBEN_O      0
#define A_SPORT2_DB_PBEN_O      0
#define A_SPORT3_CLK_PBEN_O     0
#define A_SPORT3_FS_PBEN_O      0
#define A_SPORT3_DA_PBEN_O      0
#define A_SPORT3_DB_PBEN_O      0
#define A_SPORT4_CLK_PBEN_O     0
#define A_SPORT4_FS_PBEN_O      0
#define A_SPORT4_DA_PBEN_O      0
#define A_SPORT4_DB_PBEN_O      0
#define A_SPORT5_CLK_PBEN_O     0
#define A_SPORT5_FS_PBEN_O      0
#define A_SPORT5_DA_PBEN_O      0
#define A_SPORT5_DB_PBEN_O      0
#define A_TIMER0_PBEN_O         0
#define A_TIMER1_PBEN_O         0
#define A_TIMER2_PBEN_O         0
#define A_FLAG10_PBEN_O         0
#define A_FLAG11_PBEN_O         0
#define A_FLAG12_PBEN_O         0
#define A_FLAG13_PBEN_O         0
#define A_FLAG14_PBEN_O         0
#define A_FLAG15_PBEN_O         0

// Group B dummy signals
#define B_SPORT0_CLK_O          0
#define B_SPORT1_CLK_O          0
#define B_SPORT2_CLK_O          0
#define B_SPORT3_CLK_O          0
#define B_SPORT4_CLK_O          0
#define B_SPORT5_CLK_O          0
#define B_PCG_CLKA_O            0
#define B_PCG_CLKB_O            0

#define B_SPORT0_FS_O           0
#define B_SPORT1_FS_O           0
#define B_SPORT2_FS_O           0
#define B_SPORT3_FS_O           0
#define B_SPORT4_FS_O           0
#define B_SPORT5_FS_O           0
#define B_PCG_FSA_O             0
#define B_PCG_FSB_O             0

#define B_SPORT0_CLK_O          0
#define B_SPORT1_CLK_O          0
#define B_SPORT2_CLK_O          0
#define B_SPORT3_CLK_O          0
#define B_SPORT4_CLK_O          0
#define B_SPORT5_CLK_O          0
#define B_SPORT0_FS_O           0
#define B_SPORT1_FS_O           0
#define B_SPORT2_FS_O           0
#define B_SPORT3_FS_O           0
#define B_SPORT4_FS_O           0
#define B_SPORT5_FS_O           0
#define B_TIMER0_O              0
#define B_TIMER1_O              0
#define B_TIMER2_O              0
#define B_FLAG10_O              0
#define B_MISCB2_O              0
#define B_MISCB3_O              0
#define B_MISCB4_O              0
#define B_MISCB5_O              0
#define B_FLAG11_O              0
#define B_FLAG12_O              0
#define B_FLAG13_O              0
#define B_FLAG14_O              0
#define B_PCG_CLKA_O            0
#define B_PCG_CLKB_O            0
#define B_PCG_FSA_O             0
#define B_PCG_FSB_O             0
#define B_FLAG15_O              0

#define B_TIMER0_O              0
#define B_TIMER1_O              0
#define B_TIMER2_O              0
#define B_PDAP_STRB_O           0
#define B_PCG_CLKA_O            0
#define B_PCG_FSA_O             0
#define B_PCG_CLKB_O            0
#define B_PCG_FSB_O             0

#define B_MISCA0_O              0
#define B_MISCA1_O              0
#define B_MISCA2_O              0
#define B_MISCA3_O              0
#define B_MISCA4_O              0
#define B_MISCA5_O              0
#define B_SPORT0_CLK_PBEN_O     0
#define B_SPORT0_FS_PBEN_O      0
#define B_SPORT0_DA_PBEN_O      0
#define B_SPORT0_DB_PBEN_O      0
#define B_SPORT1_CLK_PBEN_O     0
#define B_SPORT1_FS_PBEN_O      0
#define B_SPORT1_DA_PBEN_O      0
#define B_SPORT1_DB_PBEN_O      0
#define B_SPORT2_CLK_PBEN_O     0
#define B_SPORT2_FS_PBEN_O      0
#define B_SPORT2_DA_PBEN_O      0
#define B_SPORT2_DB_PBEN_O      0
#define B_SPORT3_CLK_PBEN_O     0
#define B_SPORT3_FS_PBEN_O      0
#define B_SPORT3_DA_PBEN_O      0
#define B_SPORT3_DB_PBEN_O      0
#define B_SPORT4_CLK_PBEN_O     0
#define B_SPORT4_FS_PBEN_O      0
#define B_SPORT4_DA_PBEN_O      0
#define B_SPORT4_DB_PBEN_O      0
#define B_SPORT5_CLK_PBEN_O     0
#define B_SPORT5_FS_PBEN_O      0
#define B_SPORT5_DA_PBEN_O      0
#define B_SPORT5_DB_PBEN_O      0
#define B_TIMER0_PBEN_O         0
#define B_TIMER1_PBEN_O         0
#define B_TIMER2_PBEN_O         0
#define B_FLAG10_PBEN_O         0
#define B_FLAG11_PBEN_O         0
#define B_FLAG12_PBEN_O         0
#define B_FLAG13_PBEN_O         0
#define B_FLAG14_PBEN_O         0
#define B_FLAG15_PBEN_O         0

// Group C dummy signals
#define C_SPORT0_CLK_O          0
#define C_SPORT1_CLK_O          0
#define C_SPORT2_CLK_O          0
#define C_SPORT3_CLK_O          0
#define C_SPORT4_CLK_O          0
#define C_SPORT5_CLK_O          0
#define C_PCG_CLKA_O            0
#define C_PCG_CLKB_O            0

#define C_SPORT0_DA_O           0
#define C_SPORT0_DB_O           0
#define C_SPORT1_DA_O           0
#define C_SPORT1_DB_O           0
#define C_SPORT2_DA_O           0
#define C_SPORT2_DB_O           0
#define C_SPORT3_DA_O           0
#define C_SPORT3_DB_O           0
#define C_SPORT4_DA_O           0
#define C_SPORT4_DB_O           0
#define C_SPORT5_DA_O           0
#define C_SPORT5_DB_O           0

#define C_SPORT0_DA_O           0
#define C_SPORT0_DB_O           0
#define C_SPORT1_DA_O           0
#define C_SPORT1_DB_O           0
#define C_SPORT2_DA_O           0
#define C_SPORT2_DB_O           0
#define C_SPORT3_DA_O           0
#define C_SPORT3_DB_O           0
#define C_SPORT4_DA_O           0
#define C_SPORT4_DB_O           0
#define C_SPORT5_DA_O           0
#define C_SPORT5_DB_O           0
#define C_SPORT0_CLK_O          0
#define C_SPORT1_CLK_O          0
#define C_SPORT2_CLK_O          0
#define C_SPORT3_CLK_O          0
#define C_SPORT4_CLK_O          0
#define C_SPORT5_CLK_O          0
#define C_TIMER0_O              0
#define C_TIMER1_O              0
#define C_TIMER2_O              0
#define C_FLAG10_O              0
#define C_MISCB2_O             0
#define C_MISCB3_O             0
#define C_MISCB4_O             0
#define C_MISCB5_O             0
#define C_FLAG11_O              0
#define C_FLAG12_O              0
#define C_FLAG13_O              0
#define C_FLAG14_O              0
#define C_PCG_CLKA_O            0
#define C_PCG_CLKB_O            0
#define C_FLAG15_O              0

#define C_TIMER0_O              0
#define C_TIMER1_O              0
#define C_TIMER2_O              0
#define C_PDAP_STRB_O           0
#define C_PCG_CLKA_O            0
#define C_PCG_CLKB_O            0

#define C_MISCA0_O              0
#define C_MISCA1_O              0
#define C_MISCA2_O              0
#define C_MISCA3_O              0
#define C_MISCA4_O              0
#define C_MISCA5_O              0
#define C_SPORT0_CLK_PBEN_O     0
#define C_SPORT0_FS_PBEN_O      0
#define C_SPORT0_DA_PBEN_O      0
#define C_SPORT0_DB_PBEN_O      0
#define C_SPORT1_CLK_PBEN_O     0
#define C_SPORT1_FS_PBEN_O      0
#define C_SPORT1_DA_PBEN_O      0
#define C_SPORT1_DB_PBEN_O      0
#define C_SPORT2_CLK_PBEN_O     0
#define C_SPORT2_FS_PBEN_O      0
#define C_SPORT2_DA_PBEN_O      0
#define C_SPORT2_DB_PBEN_O      0
#define C_SPORT3_CLK_PBEN_O     0
#define C_SPORT3_FS_PBEN_O      0
#define C_SPORT3_DA_PBEN_O      0
#define C_SPORT3_DB_PBEN_O      0
#define C_SPORT4_CLK_PBEN_O     0
#define C_SPORT4_FS_PBEN_O      0
#define C_SPORT4_DA_PBEN_O      0
#define C_SPORT4_DB_PBEN_O      0
#define C_SPORT5_CLK_PBEN_O     0
#define C_SPORT5_FS_PBEN_O      0
#define C_SPORT5_DA_PBEN_O      0
#define C_SPORT5_DB_PBEN_O      0
#define C_TIMER0_PBEN_O         0
#define C_TIMER1_PBEN_O         0
#define C_TIMER2_PBEN_O         0
#define C_FLAG10_PBEN_O         0
#define C_FLAG11_PBEN_O         0
#define C_FLAG12_PBEN_O         0
#define C_FLAG13_PBEN_O         0
#define C_FLAG14_PBEN_O         0
#define C_FLAG15_PBEN_O         0

// Group D dummy signals
#define D_PDAP_STRB_O           0

#define D_MISCA0_O              0
#define D_MISCA1_O              0
#define D_MISCA2_O              0
#define D_MISCA3_O              0
#define D_MISCA4_O              0
#define D_MISCA5_O              0
#define D_SPORT0_CLK_PBEN_O     0
#define D_SPORT0_FS_PBEN_O      0
#define D_SPORT0_DA_PBEN_O      0
#define D_SPORT0_DB_PBEN_O      0
#define D_SPORT1_CLK_PBEN_O     0
#define D_SPORT1_FS_PBEN_O      0
#define D_SPORT1_DA_PBEN_O      0
#define D_SPORT1_DB_PBEN_O      0
#define D_SPORT2_CLK_PBEN_O     0
#define D_SPORT2_FS_PBEN_O      0
#define D_SPORT2_DA_PBEN_O      0
#define D_SPORT2_DB_PBEN_O      0
#define D_SPORT3_CLK_PBEN_O     0
#define D_SPORT3_FS_PBEN_O      0
#define D_SPORT3_DA_PBEN_O      0
#define D_SPORT3_DB_PBEN_O      0
#define D_SPORT4_CLK_PBEN_O     0
#define D_SPORT4_FS_PBEN_O      0
#define D_SPORT4_DA_PBEN_O      0
#define D_SPORT4_DB_PBEN_O      0
#define D_SPORT5_CLK_PBEN_O     0
#define D_SPORT5_FS_PBEN_O      0
#define D_SPORT5_DA_PBEN_O      0
#define D_SPORT5_DB_PBEN_O      0
#define D_TIMER0_PBEN_O         0
#define D_TIMER1_PBEN_O         0
#define D_TIMER2_PBEN_O         0
#define D_FLAG10_PBEN_O         0
#define D_FLAG11_PBEN_O         0
#define D_FLAG12_PBEN_O         0
#define D_FLAG13_PBEN_O         0
#define D_FLAG14_PBEN_O         0
#define D_FLAG15_PBEN_O         0

// Group E dummy signals
#define E_SPORT0_CLK_O          0
#define E_SPORT1_CLK_O          0
#define E_SPORT2_CLK_O          0
#define E_SPORT3_CLK_O          0
#define E_SPORT4_CLK_O          0
#define E_SPORT5_CLK_O          0

#define E_SPORT0_DA_O           0
#define E_SPORT0_DB_O           0
#define E_SPORT1_DA_O           0
#define E_SPORT1_DB_O           0
#define E_SPORT2_DA_O           0
#define E_SPORT2_DB_O           0
#define E_SPORT3_DA_O           0
#define E_SPORT3_DB_O           0
#define E_SPORT4_DA_O           0
#define E_SPORT4_DB_O           0
#define E_SPORT5_DA_O           0
#define E_SPORT5_DB_O           0

#define E_SPORT0_FS_O           0
#define E_SPORT1_FS_O           0
#define E_SPORT2_FS_O           0
#define E_SPORT3_FS_O           0
#define E_SPORT4_FS_O           0
#define E_SPORT5_FS_O           0

#define E_SPORT0_DA_O           0
#define E_SPORT0_DB_O           0
#define E_SPORT1_DA_O           0
#define E_SPORT1_DB_O           0
#define E_SPORT2_DA_O           0
#define E_SPORT2_DB_O           0
#define E_SPORT3_DA_O           0
#define E_SPORT3_DB_O           0
#define E_SPORT4_DA_O           0
#define E_SPORT4_DB_O           0
#define E_SPORT5_DA_O           0
#define E_SPORT5_DB_O           0
#define E_SPORT0_CLK_O          0
#define E_SPORT1_CLK_O          0
#define E_SPORT2_CLK_O          0
#define E_SPORT3_CLK_O          0
#define E_SPORT4_CLK_O          0
#define E_SPORT5_CLK_O          0
#define E_SPORT0_FS_O           0
#define E_SPORT1_FS_O           0
#define E_SPORT2_FS_O           0
#define E_SPORT3_FS_O           0
#define E_SPORT4_FS_O           0
#define E_SPORT5_FS_O           0
#define E_FLAG10_O              0
#define E_MISCB2_O              0
#define E_MISCB3_O              0
#define E_MISCB4_O              0
#define E_MISCB5_O              0
#define E_FLAG11_O              0
#define E_FLAG12_O              0
#define E_FLAG13_O              0
#define E_FLAG14_O              0
#define E_FLAG15_O              0

#define E_MISCA0_O              0
#define E_MISCA1_O              0
#define E_MISCA2_O              0
#define E_MISCA3_O              0
#define E_MISCA4_O              0
#define E_MISCA5_O              0
#define E_SPORT0_CLK_PBEN_O     0
#define E_SPORT0_FS_PBEN_O      0
#define E_SPORT0_DA_PBEN_O      0
#define E_SPORT0_DB_PBEN_O      0
#define E_SPORT1_CLK_PBEN_O     0
#define E_SPORT1_FS_PBEN_O      0
#define E_SPORT1_DA_PBEN_O      0
#define E_SPORT1_DB_PBEN_O      0
#define E_SPORT2_CLK_PBEN_O     0
#define E_SPORT2_FS_PBEN_O      0
#define E_SPORT2_DA_PBEN_O      0
#define E_SPORT2_DB_PBEN_O      0
#define E_SPORT3_CLK_PBEN_O     0
#define E_SPORT3_FS_PBEN_O      0
#define E_SPORT3_DA_PBEN_O      0
#define E_SPORT3_DB_PBEN_O      0
#define E_SPORT4_CLK_PBEN_O     0
#define E_SPORT4_FS_PBEN_O      0
#define E_SPORT4_DA_PBEN_O      0
#define E_SPORT4_DB_PBEN_O      0
#define E_SPORT5_CLK_PBEN_O     0
#define E_SPORT5_FS_PBEN_O      0
#define E_SPORT5_DA_PBEN_O      0
#define E_SPORT5_DB_PBEN_O      0
#define E_TIMER0_PBEN_O         0
#define E_TIMER1_PBEN_O         0
#define E_TIMER2_PBEN_O         0
#define E_FLAG10_PBEN_O         0
#define E_FLAG11_PBEN_O         0
#define E_FLAG12_PBEN_O         0
#define E_FLAG13_PBEN_O         0
#define E_FLAG14_PBEN_O         0
#define E_FLAG15_PBEN_O         0

// Group F dummy signals
#define F_DAI_PB01_O            0
#define F_DAI_PB02_O            0
#define F_DAI_PB03_O            0
#define F_DAI_PB04_O            0
#define F_DAI_PB05_O            0
#define F_DAI_PB06_O            0
#define F_DAI_PB07_O            0
#define F_DAI_PB08_O            0
#define F_DAI_PB09_O            0
#define F_DAI_PB10_O            0
#define F_DAI_PB11_O            0
#define F_DAI_PB12_O            0
#define F_DAI_PB13_O            0
#define F_DAI_PB14_O            0
#define F_DAI_PB15_O            0
#define F_DAI_PB16_O            0
#define F_DAI_PB17_O            0
#define F_DAI_PB18_O            0
#define F_DAI_PB19_O            0
#define F_DAI_PB20_O            0
#define F_SPORT0_CLK_O          0
#define F_SPORT1_CLK_O          0
#define F_SPORT2_CLK_O          0
#define F_SPORT3_CLK_O          0
#define F_SPORT4_CLK_O          0
#define F_SPORT5_CLK_O          0
#define F_PCG_CLKA_O            0
#define F_PCG_CLKB_O            0

#define F_SPORT0_DA_O           0
#define F_SPORT0_DB_O           0
#define F_SPORT1_DA_O           0
#define F_SPORT1_DB_O           0
#define F_SPORT2_DA_O           0
#define F_SPORT2_DB_O           0
#define F_SPORT3_DA_O           0
#define F_SPORT3_DB_O           0
#define F_SPORT4_DA_O           0
#define F_SPORT4_DB_O           0
#define F_SPORT5_DA_O           0
#define F_SPORT5_DB_O           0

#define F_SPORT0_FS_O           0
#define F_SPORT1_FS_O           0
#define F_SPORT2_FS_O           0
#define F_SPORT3_FS_O           0
#define F_SPORT4_FS_O           0
#define F_SPORT5_FS_O           0
#define F_PCG_FSA_O             0
#define F_PCG_FSB_O             0

#define F_SPORT0_DA_O           0
#define F_SPORT0_DB_O           0
#define F_SPORT1_DA_O           0
#define F_SPORT1_DB_O           0
#define F_SPORT2_DA_O           0
#define F_SPORT2_DB_O           0
#define F_SPORT3_DA_O           0
#define F_SPORT3_DB_O           0
#define F_SPORT4_DA_O           0
#define F_SPORT4_DB_O           0
#define F_SPORT5_DA_O           0
#define F_SPORT5_DB_O           0
#define F_SPORT0_CLK_O          0
#define F_SPORT1_CLK_O          0
#define F_SPORT2_CLK_O          0
#define F_SPORT3_CLK_O          0
#define F_SPORT4_CLK_O          0
#define F_SPORT5_CLK_O          0
#define F_SPORT0_FS_O           0
#define F_SPORT1_FS_O           0
#define F_SPORT2_FS_O           0
#define F_SPORT3_FS_O           0
#define F_SPORT4_FS_O           0
#define F_SPORT5_FS_O           0
#define F_TIMER0_O              0
#define F_TIMER1_O              0
#define F_TIMER2_O              0
#define F_FLAG10_O              0
#define F_MISCB2_O              0
#define F_MISCB3_O              0
#define F_MISCB4_O              0
#define F_MISCB5_O              0
#define F_FLAG11_O              0
#define F_FLAG12_O              0
#define F_FLAG13_O              0
#define F_FLAG14_O              0
#define F_PCG_CLKA_O            0
#define F_PCG_CLKB_O            0
#define F_PCG_FSA_O             0
#define F_PCG_FSB_O             0
#define F_FLAG15_O              0

#define F_TIMER0_O              0
#define F_TIMER1_O              0
#define F_TIMER2_O              0
#define F_PDAP_STRB_O           0
#define F_PCG_CLKA_O            0
#define F_PCG_FSA_O             0
#define F_PCG_CLKB_O            0
#define F_PCG_FSB_O             0

// Group G dummy signals
#define G_DAI_PB01_O            0
#define G_DAI_PB02_O            0
#define G_DAI_PB03_O            0
#define G_DAI_PB04_O            0
#define G_DAI_PB05_O            0
#define G_DAI_PB06_O            0
#define G_DAI_PB07_O            0
#define G_DAI_PB08_O            0
#define G_DAI_PB09_O            0
#define G_DAI_PB10_O            0
#define G_DAI_PB11_O            0
#define G_DAI_PB12_O            0
#define G_DAI_PB13_O            0
#define G_DAI_PB14_O            0
#define G_DAI_PB15_O            0
#define G_DAI_PB16_O            0
#define G_DAI_PB17_O            0
#define G_DAI_PB18_O            0
#define G_DAI_PB19_O            0
#define G_DAI_PB20_O            0
#define G_SPORT0_CLK_O          0
#define G_SPORT1_CLK_O          0
#define G_SPORT2_CLK_O          0
#define G_SPORT3_CLK_O          0
#define G_SPORT4_CLK_O          0
#define G_SPORT5_CLK_O          0
#define G_PCG_CLKA_O            0
#define G_PCG_CLKB_O            0

#define G_SPORT0_DA_O           0
#define G_SPORT0_DB_O           0
#define G_SPORT1_DA_O           0
#define G_SPORT1_DB_O           0
#define G_SPORT2_DA_O           0
#define G_SPORT2_DB_O           0
#define G_SPORT3_DA_O           0
#define G_SPORT3_DB_O           0
#define G_SPORT4_DA_O           0
#define G_SPORT4_DB_O           0
#define G_SPORT5_DA_O           0
#define G_SPORT5_DB_O           0

#define G_SPORT0_FS_O           0
#define G_SPORT1_FS_O           0
#define G_SPORT2_FS_O           0
#define G_SPORT3_FS_O           0
#define G_SPORT4_FS_O           0
#define G_SPORT5_FS_O           0
#define G_PCG_FSA_O             0
#define G_PCG_FSB_O             0

#define G_TIMER0_O              0
#define G_TIMER1_O              0
#define G_TIMER2_O              0
#define G_FLAG10_O              0
#define G_MISCB2_O              0
#define G_MISCB3_O              0
#define G_MISCB4_O              0
#define G_MISCB5_O              0
#define G_FLAG11_O              0
#define G_FLAG12_O              0
#define G_FLAG13_O              0
#define G_FLAG14_O              0
#define G_PCG_FSA_O             0
#define G_PCG_FSB_O             0
#define G_FLAG15_O              0

#define G_TIMER0_O              0
#define G_TIMER1_O              0
#define G_TIMER2_O              0
#define G_PDAP_STRB_O           0
#define G_PCG_FSA_O             0
#define G_PCG_FSB_O             0

#define G_MISCA0_O              0
#define G_MISCA1_O              0
#define G_MISCA2_O              0
#define G_MISCA3_O              0
#define G_MISCA4_O              0
#define G_MISCA5_O              0
#define G_SPORT0_CLK_PBEN_O     0
#define G_SPORT0_FS_PBEN_O      0
#define G_SPORT0_DA_PBEN_O      0
#define G_SPORT0_DB_PBEN_O      0
#define G_SPORT1_CLK_PBEN_O     0
#define G_SPORT1_FS_PBEN_O      0
#define G_SPORT1_DA_PBEN_O      0
#define G_SPORT1_DB_PBEN_O      0
#define G_SPORT2_CLK_PBEN_O     0
#define G_SPORT2_FS_PBEN_O      0
#define G_SPORT2_DA_PBEN_O      0
#define G_SPORT2_DB_PBEN_O      0
#define G_SPORT3_CLK_PBEN_O     0
#define G_SPORT3_FS_PBEN_O      0
#define G_SPORT3_DA_PBEN_O      0
#define G_SPORT3_DB_PBEN_O      0
#define G_SPORT4_CLK_PBEN_O     0
#define G_SPORT4_FS_PBEN_O      0
#define G_SPORT4_DA_PBEN_O      0
#define G_SPORT4_DB_PBEN_O      0
#define G_SPORT5_CLK_PBEN_O     0
#define G_SPORT5_FS_PBEN_O      0
#define G_SPORT5_DA_PBEN_O      0
#define G_SPORT5_DB_PBEN_O      0
#define G_TIMER0_PBEN_O         0
#define G_TIMER1_PBEN_O         0
#define G_TIMER2_PBEN_O         0
#define G_FLAG10_PBEN_O         0
#define G_FLAG11_PBEN_O         0
#define G_FLAG12_PBEN_O         0
#define G_FLAG13_PBEN_O         0
#define G_FLAG14_PBEN_O         0
#define G_FLAG15_PBEN_O         0

